@@ -19,8 +19,12 @@ from braintree.settlement_batch_summary_gateway import SettlementBatchSummaryGat
 from braintree.subscription_gateway import SubscriptionGateway
 from braintree.testing_gateway import TestingGateway
 from braintree.transaction_gateway import TransactionGateway
+from braintree.transaction_line_item_gateway import TransactionLineItemGateway
 from braintree.transparent_redirect_gateway import TransparentRedirectGateway
 from braintree.us_bank_account_gateway import UsBankAccountGateway
+from braintree.us_bank_account_verification_gateway import UsBankAccountVerificationGateway
+# NEXT_MAJOR_VERSION Remove this class as legacy Ideal has been removed/disabled in the Braintree Gateway
+# DEPRECATED If you're looking to accept iDEAL as a payment method contact accounts@braintreepayments.com for a solution.
 from braintree.ideal_payment_gateway import IdealPaymentGateway
 from braintree.webhook_notification_gateway import WebhookNotificationGateway
 from braintree.webhook_testing_gateway import WebhookTestingGateway
@@ -52,6 +56,7 @@ class BraintreeGateway(object):
         self.settlement_batch_summary = SettlementBatchSummaryGateway(self)
         self.subscription = SubscriptionGateway(self)
         self.transaction = TransactionGateway(self)
+        self.transaction_line_item = TransactionLineItemGateway(self)
         self.transparent_redirect = TransparentRedirectGateway(self)
         self.verification = CreditCardVerificationGateway(self)
         self.webhook_notification = WebhookNotificationGateway(self)
@@ -61,4 +66,7 @@ class BraintreeGateway(object):
         self.paypal_account = PayPalAccountGateway(self)
         self.testing = TestingGateway(self)
         self.us_bank_account = UsBankAccountGateway(self)
+        self.us_bank_account_verification = UsBankAccountVerificationGateway(self)
+        # NEXT_MAJOR_VERSION Remove this class as legacy Ideal has been removed/disabled in the Braintree Gateway
+        # DEPRECATED If you're looking to accept iDEAL as a payment method contact accounts@braintreepayments.com for a solution.
         self.ideal_payment = IdealPaymentGateway(self)
