@@ -30,14 +30,15 @@ class CreditCard(Resource):
                 "country_name": "United States of America"
             },
             "options": {
-                "verify_card": True
+                "verify_card": True,
+                "verification_amount": "2.00"
             }
         })
 
         print(result.credit_card.token)
         print(result.credit_card.masked_number)
 
-    For more information on CreditCards, see https://developers.braintreepayments.com/ios+python/reference/request/credit-card/create
+    For more information on CreditCards, see https://developers.braintreepayments.com/reference/request/credit-card/create/python
 
     """
     class CardType(object):
@@ -49,8 +50,13 @@ class CreditCard(Resource):
         * Braintree.CreditCard.ChinaUnionPay
         * Braintree.CreditCard.DinersClubInternational
         * Braintree.CreditCard.Discover
+        * Braintree.CreditCard.Electron
+        * Braintree.CreditCard.Elo
+        * Braintree.CreditCard.Hiper
+        * Braintree.CreditCard.Hipercard
         * Braintree.CreditCard.JCB
         * Braintree.CreditCard.Laser
+        * Braintree.CreditCard.UK_Maestro
         * Braintree.CreditCard.Maestro
         * Braintree.CreditCard.MasterCard
         * Braintree.CreditCard.Solo
@@ -64,8 +70,13 @@ class CreditCard(Resource):
         ChinaUnionPay = "China UnionPay"
         DinersClubInternational = "Diners Club"
         Discover = "Discover"
+        Electron = "Electron"
+        Elo = "Elo"
+        Hiper = "Hiper"
+        Hipercard = "Hipercard"
         JCB = "JCB"
         Laser = "Laser"
+        UK_Maestro = "UK Maestro"
         Maestro = "Maestro"
         MasterCard = "MasterCard"
         Solo = "Solo"
@@ -97,7 +108,7 @@ class CreditCard(Resource):
         Unknown = "Unknown"
 
     Commercial = DurbinRegulated = Debit = Healthcare = \
-            CountryOfIssuance = IssuingBank = Payroll = Prepaid = CardTypeIndicator
+            CountryOfIssuance = IssuingBank = Payroll = Prepaid = ProductId = CardTypeIndicator
 
     @staticmethod
     def confirm_transparent_redirect(query_string):
@@ -179,14 +190,7 @@ class CreditCard(Resource):
     @staticmethod
     def forward(credit_card_token, receiving_merchant_id):
         """
-        Create a nonce for a credit card in your Braintree vault that can be used by another Braintree merchant.
-
-        A credit card token and a receiving merchant ID are required:
-
-            result = braintree.CreditCard.forward(
-                credit_card.token,
-                "another_merchant_public_id"
-            })
+        This method has been deprecated. Please consider the Grant API instead.
         """
 
         return Configuration.gateway().credit_card.forward(credit_card_token, receiving_merchant_id)
@@ -213,22 +217,60 @@ class CreditCard(Resource):
     @staticmethod
     def signature(type):
         billing_address_params = [
-            "company", "country_code_alpha2", "country_code_alpha3", "country_code_numeric", "country_name",
-            "extended_address", "first_name", "last_name", "locality", "postal_code", "region", "street_address"
+            "company",
+            "country_code_alpha2",
+            "country_code_alpha3",
+            "country_code_numeric",
+            "country_name",
+            "extended_address",
+            "first_name",
+            "last_name",
+            "locality",
+            "postal_code",
+            "region",
+            "street_address"
+        ]
+
+        options = [
+            "make_default",
+            "verification_merchant_account_id",
+            "verify_card",
+            "verification_amount",
+            "verification_account_type",
+            "venmo_sdk_session",
+            "fail_on_duplicate_payment_method",
+            {
+                "adyen":[
+                    "overwrite_brand",
+                    "selected_brand"
+                ]
+            }
         ]
-        options = ["make_default", "verification_merchant_account_id", "verify_card", "verification_amount", "venmo_sdk_session"]
 
         signature = [
-            "billing_address_id", "cardholder_name", "cvv", "expiration_date", "expiration_month", "expiration_year",
-            "device_session_id", "fraud_merchant_id", "number", "token", "venmo_sdk_payment_method_code", "device_data",
+            "billing_address_id",
+            "cardholder_name",
+            "cvv",
+            "expiration_date",
+            "expiration_month",
+            "expiration_year",
+            "device_session_id",
+            "fraud_merchant_id",
+            "number",
+            "token",
+            "venmo_sdk_payment_method_code",
+            "device_data",
             "payment_method_nonce",
-            {"billing_address": billing_address_params},
-            {"options": options}
+            {
+                "billing_address": billing_address_params
+            },
+            {
+                "options": options
+            }
         ]
 
         if type == "create":
             signature.append("customer_id")
-            options.append("fail_on_duplicate_payment_method")
         elif type == "update":
             billing_address_params.append({"options": ["update_existing"]})
         elif type == "update_via_customer":
