@@ -583,6 +583,9 @@ class ErrorCodes(object):
         ThreeDSecureCavvIsRequired = "915116"
         ThreeDSecureXidIsRequired = "915115"
         ThreeDSecureEciFlagIsInvalid = "915114"
+        ThreeDSecureAuthenticationResponseIsInvalid = "915120"
+        ThreeDSecureDirectoryResponseIsInvalid = "915121"
+        ThreeDSecureCavvAlgorithmIsInvalid = "915122"
         ThreeDSecureMerchantAccountDoesNotSupportCardType = "915131"
         TooManyLineItems = "915157"
         LineItemsExpected = "915158"
