@@ -9,6 +9,6 @@ class PaymentInstrumentType():
     AmexExpressCheckoutCard = "amex_express_checkout_card"
     VenmoAccount = "venmo_account"
     UsBankAccount = "us_bank_account"
-    IdealPayment = "ideal_payment"
     VisaCheckoutCard = "visa_checkout_card"
     MasterpassCard = "masterpass_card"
+    SamsungPayCard = "samsung_pay_card"
